=========
FHanalyze
=========


.. image:: https://img.shields.io/pypi/v/FHanalyze.svg
        :target: https://pypi.python.org/pypi/FHanalyze

.. image:: https://img.shields.io/travis/bitknitting/FHanalyze.svg
        :target: https://travis-ci.com/bitknitting/FHanalyze

.. image:: https://readthedocs.org/projects/FHanalyze/badge/?version=latest
        :target: https://FHanalyze.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Analyze power readings provided by the FHmonitor package.


* Free software: MIT license
* Documentation: https://FHanalyze.readthedocs.io.


Features
--------

* Gathers the readings stored by FHmonitor into the Raspberry Pi's mongodb and provides a variety of data analysis.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
